#!/bin/bash
#
# patch-icesys.sh
# Release 20200828
#
# This script patches the ICESYS initialization system.
#
# As root, run ./patch-icesys.sh
# If the installation is successful, reboot to apply changes.
#

SCRIPT="icesys_late"
BIN_PATH="/opt/ice/bin"
OK="[\033[1;32mOK\033[0m]"
FAIL="[\033[1;31mFAIL\033[0m]"

if [ $(whoami) != "root" ]; then
  echo -e "Error: this script must be run as root!  $FAIL"
  exit 1
fi

echo -e "\nInstalling $SCRIPT..."

if [ -d $BIN_PATH ]; then
  echo -e "Found target installation directory.     $OK"
else
  echo -e "Directory $BIN_PATH does not exist!      $FAIL"
  exit 1
fi

if [ -e ./$SCRIPT ]; then
  \cp ./$SCRIPT $BIN_PATH/$SCRIPT && \
  chown root:root $BIN_PATH/$SCRIPT && \
  chmod 750 $BIN_PATH/$SCRIPT
  if [ "$?" == "0" ]; then
    echo -e "The patch was successfully completed.    $OK"
    echo -e "\nPlease reboot your machine.\n"
  else
    echo -e "An error occured!                    $FAIL"
    exit 1
  fi
else
  echo -e "Error: can't find $SCRIPT!           $FAIL"
  echo "It must be located in the same directory as $0"
  exit 1
fi

exit 0
